@@ -18,7 +18,7 @@
 
 /* The interfaces in this file are subject to change at any time. */
 
-#ident "$Id: debug.h,v 1.12 2002/10/25 22:07:10 nalin Exp $"
+#ident "$Id: debug.h,v 1.13 2002/11/25 20:39:19 nalin Exp $"
 
 #ifndef vte_debug_h_included
 #define vte_debug_h_included
@@ -36,7 +36,8 @@ typedef enum {
 	VTE_DEBUG_SUBSTITUTION	= 1 << 7,
 	VTE_DEBUG_RING		= 1 << 8,
 	VTE_DEBUG_PTY		= 1 << 9,
-	VTE_DEBUG_CURSOR	= 1 << 10
+	VTE_DEBUG_CURSOR	= 1 << 10,
+	VTE_DEBUG_KEYBOARD	= 1 << 11
 } VteDebugFlags;
 
 void _vte_debug_parse_string(const char *string);
