@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: iso2022.c,v 1.13 2002/10/30 20:36:57 nalin Exp $"
+#ident "$Id: iso2022.c,v 1.14 2002/11/26 03:57:10 nalin Exp $"
 #include "config.h"
 #include <sys/types.h>
 #include <stdio.h>
@@ -73,8 +73,8 @@ static const struct _vte_iso2022_map _vte_iso2022_map_0[] = {
 	{'s', 0x23bd},  /* scan line 9/9 */
 	{'t', 0x251c},	/* left t */
 	{'u', 0x2524},	/* right t */
-	{'v', 0x252c},	/* down t */
-	{'w', 0x2534},	/* up t */
+	{'v', 0x2534},	/* bottom t */
+	{'w', 0x252c},	/* top t */
 	{'x', 0x2502},	/* vertical line */
 	{'y', 0x2264},  /* <= */
 	{'z', 0x2265},  /* >= */
