@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: trie.c,v 1.25 2002/10/11 18:50:01 nalin Exp $"
+#ident "$Id: trie.c,v 1.26 2002/12/03 02:00:45 nalin Exp $"
 #include "../config.h"
 #include <sys/types.h>
 #include <assert.h>
@@ -162,7 +162,8 @@ char_class_digit_extract(const gunichar *s, size_t length,
 	GValue value;
 	for (i = 0; i < length; i++) {
 		ret *= 10;
-		ret += (s[i] - '0');
+		ret += g_unichar_digit_value(s[i]) == -1 ?
+		       0 : g_unichar_digit_value(s[i]);
 	}
 	memset(&value, 0, sizeof(value));
 	g_value_init(&value, G_TYPE_LONG);
